package com.qmth.boot.test.core.metrics;

import com.qmth.boot.core.metrics.config.MetricsProperties;
import com.qmth.boot.core.metrics.model.MetricsResult;
import com.qmth.boot.core.metrics.model.TimeRange;
import com.qmth.boot.core.metrics.service.impl.MemoryMetricsService;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

import java.util.List;

public class MetricsTest {

    private static MemoryMetricsService service;

    private static MetricsProperties config;

    @BeforeClass
    public static void prepare() {
        config = new MetricsProperties();
        service = new MemoryMetricsService(config);
    }

    @AfterClass
    public static void clear() {
        service.reset();
    }

    @Test
    public void testSingleEndpoint() {
        service.record("/a1", 200, 8);
        service.record("/a1", 200, 22);
        service.record("/a1", 200, 130);
        service.record("/a1", 400, 12);
        service.record("/a1", 500, 33);
        service.record("/a1", 401, 330);
        service.record("/a1", 404, 1209);
        List<MetricsResult> list = service.result();
        Assert.assertEquals(1, list.size());
        MetricsResult result = list.get(0);
        Assert.assertEquals(5, result.getStatus().size());
        Assert.assertEquals(3, result.getStatus().get(200).longValue());
        Assert.assertEquals(3, result.getTime().get(new TimeRange(10, 100)).longValue());
        Assert.assertEquals(0, result.getTime().get(new TimeRange(10000, -1)).longValue());
    }

}
