package com.qmth.boot.api.interceptor.impl;

import com.qmth.boot.api.config.ApiProperties;
import com.qmth.boot.api.exception.DefaultExceptionEnum;
import com.qmth.boot.api.interceptor.AbstractInterceptor;
import com.qmth.boot.api.utils.RequestUtil;
import com.qmth.boot.core.rateLimit.entity.RateLimitRule;
import com.qmth.boot.core.rateLimit.service.RateLimitPolicy;
import com.qmth.boot.core.rateLimit.service.RateLimitService;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@Component
public class RateLimitInterceptor extends AbstractInterceptor {

    @Resource
    private ApiProperties apiProperties;

    @Resource
    private RateLimitService rateLimitService;

    @Autowired(required = false)
    private RateLimitPolicy rateLimitPolicy;

    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        String path = request.getServletPath();
        RateLimitRule[] rules = rateLimitPolicy != null ? rateLimitPolicy.getRules(path) : null;
        if (ArrayUtils.isEmpty(rules)) {
            rules = getAacConfig(apiProperties, request, handler).getRateLimit();
        }
        String device = getDeviceIdOrIpAddress(request);
        // 所有限流规则需要全部匹配才通过
        for (RateLimitRule rule : rules) {
            if (!rateLimitService.accept(path, device, rule)) {
                log.warn("Rate limited: path={}, rule={}, device={}", path, rule.toString(), device);
                throw DefaultExceptionEnum.RATE_LIMITED.exception();
            }
        }
        return true;
    }

    private String getDeviceIdOrIpAddress(HttpServletRequest request) {
        // deviceId不存在时取IP地址作为设备标识
        String device = StringUtils.trimToNull(request.getHeader(HEADER_DEVICE_ID));
        if (device == null) {
            device = RequestUtil.getIpAddress(request);
        }
        return device;
    }

}
